@@ -137,14 +137,6 @@ PASSWORD_PARAMETER_NAMES = (
     'SwiftPassword',
     'ZaqarPassword',
 )
-# List of legacy resource names from overcloud.yaml
-LEGACY_HEAT_PASSWORD_RESOURCE_NAMES = (
-    'HeatAuthEncryptionKey',
-    'HorizonSecret',
-    'MysqlRootPassword',
-    'PcsdPassword',
-    'RabbitCookie',
-)
 
 # List of passwords that should not be rotated by default using the
 # GeneratePasswordAction because they require some special handling
@@ -187,9 +179,16 @@ USER_ENVIRONMENT = 'user-environment.yaml'
 CONTAINER_DEFAULTS_ENVIRONMENT = ('environments/'
                                   'containers-default-parameters.yaml')
 
+DEFAULT_DEPLOY_KERNEL_NAME = 'bm-deploy-kernel'
+
+DEFAULT_DEPLOY_RAMDISK_NAME = 'bm-deploy-ramdisk'
+
 # The name for the swift container to host the cache for tripleo
 TRIPLEO_CACHE_CONTAINER = "__cache__"
 
+TRIPLEO_UI_LOG_FILE_SIZE = 1e7  # 10MB
+TRIPLEO_UI_LOG_FILENAME = 'tripleo-ui.logs'
+
 API_NETWORK = 'InternalApi'
 LEGACY_API_NETWORK = 'Internal'
 
@@ -199,14 +198,21 @@ NESTED_DEPTH = 7
 # Resource name for deployment resources when using config download
 TRIPLEO_DEPLOYMENT_RESOURCE = 'TripleODeployment'
 
+# Resource name for network config resources when using config download
+TRIPLEO_NETWORK_CONFIG_RESOURCE = 'NetworkConfig'
+
 HOST_NETWORK = 'ctlplane'
 
+DEFAULT_VLAN_ID = "1"
+
 # The key is different in RoleConfig than in RoleData, so we need both so they
 # are correctly found.
 EXTERNAL_TASKS = ['external_deploy_tasks', 'external_deploy_steps_tasks']
 
 ANSIBLE_ERRORS_FILE = 'ansible-errors.json'
 
+DEPLOYMENT_STATUS_FILE = 'deployment_status.yaml'
+
 MISTRAL_WORK_DIR = '/var/lib/mistral'
 
 EXCLUSIVE_NEUTRON_DRIVERS = ['ovn', 'openvswitch']
@@ -221,3 +227,5 @@ PER_STEP_TASKS = {
     'update_tasks': _PER_STEP_TASK_STRICTNESS,
     'post_update_tasks': [False, False, False, False]
 }
+
+INVENTORY_NETWORK_CONFIG_FILE = 'inventory-network-config.yaml'
